@@ -5,11 +5,13 @@
 # This should be started from rc.firewall.
 # This script only affect the IPv6 rules and configuration located
 # in /etc/shorewall6
+#
+# http://rafb.net/p/1gsyye11.html 
 
 OPTIONS=""
 
-# Use /etc/default/shorewall6 to specify $OPTIONS to run at startup; however,
-# this might prevent shorewall6 from starting. Use at your own risk...
+# Use /etc/default shorewall6 to specify $OPTIONS to run at startup, however this
+# this might prevent shorewall6 from starting. use at your own risk
 if [ -f /etc/default/shorewall6 ] ; then
     . /etc/default/shorewall6
 fi
@@ -49,9 +51,9 @@ case "$1" in
 	;;
     *)
 		echo "Usage: $0 start|stop|reload|restart|status"
-		exit 1
 	;;
 esac
 
 exit 0
 
+# All done
